SystemOrganization addCategory: #ConfigurationOfXPath!

Object subclass: #ConfigurationOfXPath
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXPath'!

!ConfigurationOfXPath class methodsFor: 'development support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 1/31/2014 12:31'!
catalogChangeLog
    		
     ^ '- Version 1.0 migrated to Pharo 3.0'

! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 1/31/2014 12:28'!
catalogContactInfo
	^ 'hernan.morales@gmail.com'! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 1/31/2014 12:28'!
catalogDescription

	^ 'A basic XPath library for Squeak and Pharo, leveraging the XML parsing capabilities now included in the base image. Modifies XMLNode to better support XPath. Handles basic XPath locator expressions for elements and attributes; returns a collection of XMLNodes matching the expression, if any.'! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 1/31/2014 12:30'!
catalogKeyClassesAndExample

	^ ' ==XPath== is the main public class of the package. It is the class to interact with as shown by the tests. 

The following example retrieves the language types as found in the UNICODE Common Locale Data Repository (CDLR) 
[[[ 
| doc |
doc := (XMLDOMParser onURL: ''http://unicode.org/repos/cldr/trunk/common/supplemental/supplementalData.xml'') parseDocument.
(XPath for: ''/languageData/language/@type'') in: doc.
]]]

The package contains SUnit tests in the XPathTest class.'! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'HernanMoralesDurand 1/31/2014 12:28'!
catalogKeywords
	^ #(XPath XML web query parsing)! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfXPath class methodsFor: 'metacello tool support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfXPath class methodsFor: 'accessing' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
project

	^self new project! !

!ConfigurationOfXPath class methodsFor: 'development support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/9/2015 23:59'!
baseline101: spec
	<version: '1.0.1-baseline' imports: #('1.0-baseline')>

	spec for: #gemstone do: [
		spec blessing: #baseline.
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.2'. ].! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/11/2015 01:20'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.smalltalkhub.com/mc/PharoExtras/XPath/main'.
		spec project: 'XMLParser' with: [ 
			spec
				className: 'ConfigurationOfXMLParser';
				loads: #('default');	
				versionString: #'stable';
				repository: 'http://www.smalltalkhub.com/mc/PharoExtras/XMLParser/main' ].
		spec package: 'XPath-Core' with: [ spec requires: 'XMLParser' ].
		spec package: 'XPath-Tests' with: [ spec requires: 'XPath-Core' ].

		spec group: 'default' with: #('Core' 'Tests').
		spec group: 'Core' with: #('XPath-Core').
		spec group: 'Tests' with: #('XPath-Tests'). ].

	"load gemstone methods"
	spec for: #'gemstone' do: [
		spec
			package: 'XPath-Core'
			with: [ spec includes: 'XPath-GemstoneCompatibility' ].
		spec
			package: 'XPath-GemstoneCompatibility'
			with: [ spec requires: 'XPath-Core' ]. ].! !

!ConfigurationOfXPath methodsFor: 'accessing' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfXPath methodsFor: 'symbolic versions' stamp: 'monty 2/10/2015 00:05'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0.1-baseline'.! !

!ConfigurationOfXPath methodsFor: 'accessing' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXPath methodsFor: 'symbolic versions' stamp: 'monty 2/10/2015 00:14'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0.1'.
! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/11/2015 01:20'!
version101: spec 
        <version: '1.0.1' imports: #('1.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.8'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.4'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'HernanMoralesDurand 1/31/2014 12:31'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: ''.
		spec author: 'HernanMoralesDurand'.

		spec timestamp: '31/1/2014 21:15'.
		spec package: 'XPath' with: 'XPath-HernanMoralesDurand.12'. ].
! !
